@@ -11,6 +11,7 @@ import (
 	"fmt"
 	"os"
 	"os/exec"
+	"path/filepath"
 	"strings"
 )
 
@@ -52,7 +53,7 @@ type SystemImage interface {
 type CoreImage interface {
 	Image
 	SystemImage
-	SetupBoot() error
+	SetupBoot(OemDescription) error
 	FlashExtra(string) error
 }
 
@@ -64,6 +65,18 @@ type HardwareDescription struct {
 	Bootloader      string `yaml:"bootloader"`
 }
 
+type OemDescription struct {
+	Name     string `yaml:"name"`
+	Version  string `yaml:"version"`
+	Hardware struct {
+		Dtb string `yaml:"dtb,omitempty"`
+	} `yaml:"hardware,omitempty"`
+}
+
+func (o OemDescription) InstallPath() string {
+	return filepath.Join("/oem", o.Name, o.Version)
+}
+
 func sectorSize(dev string) (string, error) {
 	out, err := exec.Command("blockdev", "--getss", dev).CombinedOutput()
 	if err != nil {
